<?php

namespace Relawan\Program\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Relawan\Program\Http\Requests\ProgramAdminRequest;
use Relawan\Program\Interfaces\ProgramRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class ProgramAdminController extends AdminController
{
    /**
     * Initialize program controller.
     *
     * @param type ProgramRepositoryInterface $program
     *
     * @return type
     */
    public function __construct(ProgramRepositoryInterface $program)
    {
        $this->model = $program;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(ProgramAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('program.program.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('program::program.names').' :: ');

        return $this->theme->of('program::admin.program.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(ProgramAdminRequest $request, $id)
    {
        $program = $this->model->find($id);

        if (empty($program)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('program::admin.program.new');
        }

        if ($request->wantsJson()) {
            return $program;
        }

        Former::populate($program);

        return view('program::admin.program.show', compact('program'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(ProgramAdminRequest $request)
    {
        $program = $this->model->findOrNew(0);
        Former::populate($program);

        return view('program::admin.program.create', compact('program'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(ProgramAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $program = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('program::program.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(ProgramAdminRequest $request, $id)
    {
        $program = $this->model->find($id);

        Former::populate($program);

        return view('program::admin.program.edit', compact('program'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(ProgramAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $program = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('program::program.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(ProgramAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('program::program.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
